#!btsave
##################################
##
## btsave
##
## tries to autodetect name
## and origin of a theme.
## then tries to save it in
## either plaintext or the .bt
## theme format
##
## the user is asked if he/she wants
## to write to a certain file.
##
##################################

## bashish by default saves themes from 
## it's current path.
## this makes it possible to save themes
## located in non-standard places
## eg. $BASHISH_USERDIR/bt/app/alsamixer/
if test -f "$PWD/theme" ;then

	## get themename if possible
	THEME="`cat $PWD/themename 2>/dev/null`"
	
	## by default, save as plaintext themes
	## without compressing the content in .bt 
	## files
	POSTFIX=""
	
	## load the theme
	. $PWD/theme 2>/dev/null
	
	## test if various files exist, if one of these
	## exists, bashish will save the file in the .bt
	## format.
	test -f "$PWD/$XFONT"&&NEEDBT=1
	test -f "$PWD/$CFONT"&&NEEDBT=1
	test -f "$PWD/$LOGO"&&NEEDBT=1
	test -f "$PWD/$EICON"&&NEEDBT=1
	test -f "$PWD/$DTICON"&&NEEDBT=1
	test -f "$PWD/$IMAGEFILE"&&NEEDBT=1
	test -f "$PWD/$IMAGELOGO"&&NEEDBT=1
	test -f "$PWD/$ASCII_LOGO"&&NEEDBT=1

	## clean variables that contains bogus values
	## or isn't located in the themedir
	test -f "$PWD/$XFONT"||XFONT=""
	test -f "$PWD/$CFONT"||CFONT=""
	test -f "$PWD/$EICON"||EICON=""
	test -f "$PWD/$DTICON"||DTICON=""
	test -f "$PWD/$IMAGEFILE"||IMAGEFILE=""
	test -f "$PWD/$IMAGELOGO"||IMAGELOGO=""
	test -f "$PWD/$ASCII_LOGO"||ASCII_LOGO=""

	if test "$NEEDBT" = 1 ; then
		POSTFIX=".bt"
	fi
	
	## search for existing filename
	for BTFILE in `find $BASHISH_USERDIR/themes $BASHISHDIR/themes -type f -name "$THEME$POSTFIX"`
	do
		## assign $BTFILE to first found filename
		break
	done
	
	## query the user wether he wants to write to the guessed file.
	if test -f "$BTFILE";then
		printf "\nbashish: would you like to write to\nbashish: $BTFILE [y/n]\n"
		read INPUT
	else
		INPUT=no
	fi
	case "$INPUT" in
	n*|N*|0*)
		printf "bashish: Enter new filename $BASHISH_USERDIR/themes/";read BTFILE
		BTFILE="$BASHISH_USERDIR/themes/$BTFILE"
	esac
	
	## add a 
	test "$NEEDBT" = 1 && case "$BTFILE" in
	*.bt)
		:
		;;
	*)
		BTFILE=$BTFILE.bt
	esac
	
	## remove files prior to overwriting them
	## some shells can be hairy about file clobbering
	test -f $BTFILE&&/bin/rm "$BTFILE"
	case "$BTFILE" in
	*.bt)
		## compatible compression with tar, non-gnutar's mostly doesn't have the -z switch.
		## write as .bt
		tar -c theme $XFONT $CFONT $EICON $DTICON $IMAGEFILE $IMAGELOGO $ASCII_LOGO |gzip -cqf 1>$BTFILE && echo "SUCCESS: file was saved to $BTFILE
		"
	;;
	*)
		## write as plaintext
		cat $PWD/theme 1> "$BTFILE"&& echo "SUCCESS: file was saved to $BTFILE
		"
		## remove the (older) .bt file since it would otherwise be prefered by "changetheme"
		## instead of the plain-text theme we just saved
		test -f ${BTFILE}.bt&&/bin/rm ${BTFILE}.bt
	esac
	
	## clean some variables
	unset BTFILE POSTFIX
else
	printf "
btsave: this program must be executed from the themedirectory you intend to save from.
btsave:
btsave: type 'cd \$BTDIR' to get to the main theme directory

"
fi
